# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_meta import (
    V0041OpenapiSlurmdbdJobsRespMeta,
)


class TestV0041OpenapiSlurmdbdJobsRespMeta(unittest.TestCase):
    """V0041OpenapiSlurmdbdJobsRespMeta unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiSlurmdbdJobsRespMeta:
        """Test V0041OpenapiSlurmdbdJobsRespMeta
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdJobsRespMeta`
        """
        model = V0041OpenapiSlurmdbdJobsRespMeta()
        if include_optional:
            return V0041OpenapiSlurmdbdJobsRespMeta(
                plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                    type = '',
                    name = '',
                    data_parser = '',
                    accounting_storage = '', ),
                client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                    source = '',
                    user = '',
                    group = '', ),
                command = [
                    ''
                    ],
                slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                    version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                        major = '',
                        micro = '',
                        minor = '', ),
                    release = '',
                    cluster = '', )
            )
        else:
            return V0041OpenapiSlurmdbdJobsRespMeta(
        )
        """

    def testV0041OpenapiSlurmdbdJobsRespMeta(self):
        """Test V0041OpenapiSlurmdbdJobsRespMeta"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
