# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_job_array import V0042JobArray


class TestV0042JobArray(unittest.TestCase):
    """V0042JobArray unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042JobArray:
        """Test V0042JobArray
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042JobArray`
        """
        model = V0042JobArray()
        if include_optional:
            return V0042JobArray(
                job_id = 56,
                limits = slurmrestpy.models.v0_0_42_job_array_limits.v0_0_42_job_array_limits(
                    max = slurmrestpy.models.v0_0_42_job_array_limits_max.v0_0_42_job_array_limits_max(
                        running = slurmrestpy.models.v0_0_42_job_array_limits_max_running.v0_0_42_job_array_limits_max_running(
                            tasks = 56, ), ), ),
                task_id = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                task = ''
            )
        else:
            return V0042JobArray(
        )
        """

    def testV0042JobArray(self):
        """Test V0042JobArray"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
