# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_consumed import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed,
)


class TestV0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed(
    unittest.TestCase
):
    """V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed:
        """Test V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed`
        """
        model = V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed()
        if include_optional:
            return V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed(
                max = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                min = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                average = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                total = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ]
            )
        else:
            return V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed(
        )
        """

    def testV0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed(self):
        """Test V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
