# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_cluster_rec import V0040ClusterRec


class TestV0040ClusterRec(unittest.TestCase):
    """V0040ClusterRec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040ClusterRec:
        """Test V0040ClusterRec
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040ClusterRec`
        """
        model = V0040ClusterRec()
        if include_optional:
            return V0040ClusterRec(
                controller = slurmrestpy.models.v0_0_42_cluster_rec_controller.v0_0_42_cluster_rec_controller(
                    host = '',
                    port = 56, ),
                flags = [
                    'REGISTERING'
                    ],
                name = '',
                nodes = '',
                select_plugin = '',
                associations = slurmrestpy.models.v0_0_40_cluster_rec_associations.v0_0_40_cluster_rec_associations(
                    root = slurmrestpy.models.v0/0/40_assoc_short.v0.0.40_assoc_short(
                        account = '',
                        cluster = '',
                        partition = '',
                        user = '',
                        id = 56, ), ),
                rpc_version = 56,
                tres = [
                    slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ]
            )
        else:
            return V0040ClusterRec(
        )
        """

    def testV0040ClusterRec(self):
        """Test V0040ClusterRec"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
