# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_job_alloc_req import V0041JobAllocReq


class TestV0041JobAllocReq(unittest.TestCase):
    """V0041JobAllocReq unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041JobAllocReq:
        """Test V0041JobAllocReq
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041JobAllocReq`
        """
        model = V0041JobAllocReq()
        if include_optional:
            return V0041JobAllocReq(
                hetjob = [
                    slurmrestpy.models.v0/0/41_job_desc_msg.v0.0.41_job_desc_msg(
                        account = '',
                        account_gather_frequency = '',
                        admin_comment = '',
                        allocation_node_list = '',
                        allocation_node_port = 56,
                        argv = [
                            ''
                            ],
                        array = '',
                        batch_features = '',
                        begin_time = slurmrestpy.models.v0_0_41_job_desc_msg_begin_time.v0_0_41_job_desc_msg_begin_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        flags = [
                            'KILL_INVALID_DEPENDENCY'
                            ],
                        burst_buffer = '',
                        clusters = '',
                        cluster_constraint = '',
                        comment = '',
                        contiguous = True,
                        container = '',
                        container_id = '',
                        core_specification = 56,
                        thread_specification = 56,
                        cpu_binding = '',
                        cpu_binding_flags = [
                            'CPU_BIND_TO_THREADS'
                            ],
                        cpu_frequency = '',
                        cpus_per_tres = '',
                        crontab = slurmrestpy.models.v0_0_41_job_desc_msg_crontab.v0_0_41_job_desc_msg_crontab(
                            minute = '',
                            hour = '',
                            day_of_month = '',
                            month = '',
                            day_of_week = '',
                            specification = '',
                            command = '',
                            line = slurmrestpy.models.v0_0_42_cron_entry_line.v0_0_42_cron_entry_line(
                                start = 56,
                                end = 56, ), ),
                        deadline = 56,
                        delay_boot = 56,
                        dependency = '',
                        end_time = 56,
                        environment = [
                            ''
                            ],
                        rlimits = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits.v0_0_41_job_desc_msg_rlimits(
                            cpu = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_cpu.v0_0_41_job_desc_msg_rlimits_cpu(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            fsize = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_fsize.v0_0_41_job_desc_msg_rlimits_fsize(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            data = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_data.v0_0_41_job_desc_msg_rlimits_data(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            stack = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_stack.v0_0_41_job_desc_msg_rlimits_stack(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            core = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_core.v0_0_41_job_desc_msg_rlimits_core(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            rss = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_rss.v0_0_41_job_desc_msg_rlimits_rss(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            nproc = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_nproc.v0_0_41_job_desc_msg_rlimits_nproc(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            nofile = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_nofile.v0_0_41_job_desc_msg_rlimits_nofile(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            memlock = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_memlock.v0_0_41_job_desc_msg_rlimits_memlock(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            as = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_as.v0_0_41_job_desc_msg_rlimits_as(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        excluded_nodes = [
                            ''
                            ],
                        extra = '',
                        constraints = '',
                        group_id = '',
                        hetjob_group = 56,
                        immediate = True,
                        job_id = 56,
                        kill_on_node_fail = True,
                        licenses = '',
                        mail_type = [
                            'BEGIN'
                            ],
                        mail_user = '',
                        mcs_label = '',
                        memory_binding = '',
                        memory_binding_type = [
                            'NONE'
                            ],
                        memory_per_tres = '',
                        name = '',
                        network = '',
                        nice = 56,
                        tasks = 56,
                        open_mode = [
                            'APPEND'
                            ],
                        reserve_ports = 56,
                        overcommit = True,
                        partition = '',
                        distribution_plane_size = slurmrestpy.models.v0_0_41_job_desc_msg_distribution_plane_size.v0_0_41_job_desc_msg_distribution_plane_size(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        power_flags = [
                            null
                            ],
                        prefer = '',
                        hold = True,
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        profile = [
                            'NOT_SET'
                            ],
                        qos = '',
                        reboot = True,
                        required_nodes = [
                            ''
                            ],
                        requeue = True,
                        reservation = '',
                        resv_mpi_ports = 56,
                        script = '',
                        shared = [
                            'none'
                            ],
                        exclusive = [
                            'true'
                            ],
                        oversubscribe = True,
                        site_factor = 56,
                        spank_environment = [
                            ''
                            ],
                        distribution = '',
                        time_limit = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        time_minimum = slurmrestpy.models.v0_0_41_job_desc_msg_time_minimum.v0_0_41_job_desc_msg_time_minimum(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tres_bind = '',
                        tres_freq = '',
                        tres_per_job = '',
                        tres_per_node = '',
                        tres_per_socket = '',
                        tres_per_task = '',
                        user_id = '',
                        wait_all_nodes = True,
                        kill_warning_flags = [
                            'BATCH_JOB'
                            ],
                        kill_warning_signal = '',
                        kill_warning_delay = slurmrestpy.models.v0_0_41_job_desc_msg_kill_warning_delay.v0_0_41_job_desc_msg_kill_warning_delay(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        current_working_directory = '',
                        cpus_per_task = 56,
                        minimum_cpus = 56,
                        maximum_cpus = 56,
                        nodes = '',
                        minimum_nodes = 56,
                        maximum_nodes = 56,
                        minimum_boards_per_node = 56,
                        minimum_sockets_per_board = 56,
                        sockets_per_node = 56,
                        threads_per_core = 56,
                        tasks_per_node = 56,
                        tasks_per_socket = 56,
                        tasks_per_core = 56,
                        tasks_per_board = 56,
                        ntasks_per_tres = 56,
                        minimum_cpus_per_node = 56,
                        memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        memory_per_node = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        temporary_disk_per_node = 56,
                        selinux_context = '',
                        required_switches = slurmrestpy.models.v0_0_41_job_desc_msg_required_switches.v0_0_41_job_desc_msg_required_switches(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        segment_size = slurmrestpy.models.v0_0_41_job_desc_msg_segment_size.v0_0_41_job_desc_msg_segment_size(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        standard_error = '',
                        standard_input = '',
                        standard_output = '',
                        wait_for_switch = 56,
                        wckey = '',
                        x11 = [
                            'FORWARD_ALL_NODES'
                            ],
                        x11_magic_cookie = '',
                        x11_target_host = '',
                        x11_target_port = 56, )
                    ],
                job = slurmrestpy.models.v0/0/41_job_desc_msg.v0.0.41_job_desc_msg(
                    account = '',
                    account_gather_frequency = '',
                    admin_comment = '',
                    allocation_node_list = '',
                    allocation_node_port = 56,
                    argv = [
                        ''
                        ],
                    array = '',
                    batch_features = '',
                    begin_time = slurmrestpy.models.v0_0_41_job_desc_msg_begin_time.v0_0_41_job_desc_msg_begin_time(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    flags = [
                        'KILL_INVALID_DEPENDENCY'
                        ],
                    burst_buffer = '',
                    clusters = '',
                    cluster_constraint = '',
                    comment = '',
                    contiguous = True,
                    container = '',
                    container_id = '',
                    core_specification = 56,
                    thread_specification = 56,
                    cpu_binding = '',
                    cpu_binding_flags = [
                        'CPU_BIND_TO_THREADS'
                        ],
                    cpu_frequency = '',
                    cpus_per_tres = '',
                    crontab = slurmrestpy.models.v0_0_41_job_desc_msg_crontab.v0_0_41_job_desc_msg_crontab(
                        minute = '',
                        hour = '',
                        day_of_month = '',
                        month = '',
                        day_of_week = '',
                        specification = '',
                        command = '',
                        line = slurmrestpy.models.v0_0_42_cron_entry_line.v0_0_42_cron_entry_line(
                            start = 56,
                            end = 56, ), ),
                    deadline = 56,
                    delay_boot = 56,
                    dependency = '',
                    end_time = 56,
                    environment = [
                        ''
                        ],
                    rlimits = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits.v0_0_41_job_desc_msg_rlimits(
                        cpu = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_cpu.v0_0_41_job_desc_msg_rlimits_cpu(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        fsize = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_fsize.v0_0_41_job_desc_msg_rlimits_fsize(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        data = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_data.v0_0_41_job_desc_msg_rlimits_data(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        stack = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_stack.v0_0_41_job_desc_msg_rlimits_stack(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        core = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_core.v0_0_41_job_desc_msg_rlimits_core(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        rss = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_rss.v0_0_41_job_desc_msg_rlimits_rss(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        nproc = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_nproc.v0_0_41_job_desc_msg_rlimits_nproc(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        nofile = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_nofile.v0_0_41_job_desc_msg_rlimits_nofile(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        memlock = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_memlock.v0_0_41_job_desc_msg_rlimits_memlock(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        as = slurmrestpy.models.v0_0_41_job_desc_msg_rlimits_as.v0_0_41_job_desc_msg_rlimits_as(
                            set = True,
                            infinite = True,
                            number = 56, ), ),
                    excluded_nodes = [
                        ''
                        ],
                    extra = '',
                    constraints = '',
                    group_id = '',
                    hetjob_group = 56,
                    immediate = True,
                    job_id = 56,
                    kill_on_node_fail = True,
                    licenses = '',
                    mail_type = [
                        'BEGIN'
                        ],
                    mail_user = '',
                    mcs_label = '',
                    memory_binding = '',
                    memory_binding_type = [
                        'NONE'
                        ],
                    memory_per_tres = '',
                    name = '',
                    network = '',
                    nice = 56,
                    tasks = 56,
                    open_mode = [
                        'APPEND'
                        ],
                    reserve_ports = 56,
                    overcommit = True,
                    partition = '',
                    distribution_plane_size = slurmrestpy.models.v0_0_41_job_desc_msg_distribution_plane_size.v0_0_41_job_desc_msg_distribution_plane_size(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    power_flags = [
                        null
                        ],
                    prefer = '',
                    hold = True,
                    priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    profile = [
                        'NOT_SET'
                        ],
                    qos = '',
                    reboot = True,
                    required_nodes = [
                        ''
                        ],
                    requeue = True,
                    reservation = '',
                    resv_mpi_ports = 56,
                    script = '',
                    shared = [
                        'none'
                        ],
                    exclusive = [
                        'true'
                        ],
                    oversubscribe = True,
                    site_factor = 56,
                    spank_environment = [
                        ''
                        ],
                    distribution = '',
                    time_limit = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    time_minimum = slurmrestpy.models.v0_0_41_job_desc_msg_time_minimum.v0_0_41_job_desc_msg_time_minimum(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    tres_bind = '',
                    tres_freq = '',
                    tres_per_job = '',
                    tres_per_node = '',
                    tres_per_socket = '',
                    tres_per_task = '',
                    user_id = '',
                    wait_all_nodes = True,
                    kill_warning_flags = [
                        'BATCH_JOB'
                        ],
                    kill_warning_signal = '',
                    kill_warning_delay = slurmrestpy.models.v0_0_41_job_desc_msg_kill_warning_delay.v0_0_41_job_desc_msg_kill_warning_delay(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    current_working_directory = '',
                    cpus_per_task = 56,
                    minimum_cpus = 56,
                    maximum_cpus = 56,
                    nodes = '',
                    minimum_nodes = 56,
                    maximum_nodes = 56,
                    minimum_boards_per_node = 56,
                    minimum_sockets_per_board = 56,
                    sockets_per_node = 56,
                    threads_per_core = 56,
                    tasks_per_node = 56,
                    tasks_per_socket = 56,
                    tasks_per_core = 56,
                    tasks_per_board = 56,
                    ntasks_per_tres = 56,
                    minimum_cpus_per_node = 56,
                    memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    memory_per_node = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    temporary_disk_per_node = 56,
                    selinux_context = '',
                    required_switches = slurmrestpy.models.v0_0_41_job_desc_msg_required_switches.v0_0_41_job_desc_msg_required_switches(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    segment_size = slurmrestpy.models.v0_0_41_job_desc_msg_segment_size.v0_0_41_job_desc_msg_segment_size(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    standard_error = '',
                    standard_input = '',
                    standard_output = '',
                    wait_for_switch = 56,
                    wckey = '',
                    x11 = [
                        'FORWARD_ALL_NODES'
                        ],
                    x11_magic_cookie = '',
                    x11_target_host = '',
                    x11_target_port = 56, )
            )
        else:
            return V0041JobAllocReq(
        )
        """

    def testV0041JobAllocReq(self):
        """Test V0041JobAllocReq"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
