# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_qos_resp import (
    V0041OpenapiSlurmdbdQosResp,
)


class TestV0041OpenapiSlurmdbdQosResp(unittest.TestCase):
    """V0041OpenapiSlurmdbdQosResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiSlurmdbdQosResp:
        """Test V0041OpenapiSlurmdbdQosResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdQosResp`
        """
        model = V0041OpenapiSlurmdbdQosResp()
        if include_optional:
            return V0041OpenapiSlurmdbdQosResp(
                qos = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner.v0_0_41_openapi_slurmdbd_config_resp_qos_inner(
                        description = '',
                        flags = [
                            'NOT_SET'
                            ],
                        id = 56,
                        limits = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits(
                            grace_time = 56,
                            max = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max(
                                active_jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs(
                                    accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing(
                                        set = True,
                                        infinite = True,
                                        number = 56, ),
                                    count = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count(
                                        set = True,
                                        infinite = True,
                                        number = 56, ), ),
                                tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres(
                                    total = [
                                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                            type = '',
                                            name = '',
                                            id = 56, )
                                        ],
                                    minutes = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes(
                                        per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per(
                                            qos = [
                                                slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                                    type = '',
                                                    name = '',
                                                    id = 56, )
                                                ],
                                            job = [

                                                ],
                                            account = [

                                                ],
                                            user = [

                                                ], ), ),
                                    per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per(
                                        node = [

                                            ], ), ),
                                wall_clock = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock(),
                                jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs(),
                                accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing(), ),
                            factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            min = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min(
                                priority_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold(
                                    set = True,
                                    infinite = True,
                                    number = 56, ), ), ),
                        name = '',
                        preempt = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt(
                            list = [
                                ''
                                ],
                            mode = [
                                'DISABLED'
                                ],
                            exempt_time = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_priority.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        usage_factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_factor(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        usage_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_threshold(
                            set = True,
                            infinite = True,
                            number = 1.337, ), )
                    ],
                meta = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_meta.v0_0_41_openapi_slurmdbd_jobs_resp_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0041OpenapiSlurmdbdQosResp(
                qos = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner.v0_0_41_openapi_slurmdbd_config_resp_qos_inner(
                        description = '',
                        flags = [
                            'NOT_SET'
                            ],
                        id = 56,
                        limits = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits(
                            grace_time = 56,
                            max = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max(
                                active_jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs(
                                    accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing(
                                        set = True,
                                        infinite = True,
                                        number = 56, ),
                                    count = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count(
                                        set = True,
                                        infinite = True,
                                        number = 56, ), ),
                                tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres(
                                    total = [
                                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                            type = '',
                                            name = '',
                                            id = 56, )
                                        ],
                                    minutes = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes(
                                        per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per(
                                            qos = [
                                                slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                                    type = '',
                                                    name = '',
                                                    id = 56, )
                                                ],
                                            job = [

                                                ],
                                            account = [

                                                ],
                                            user = [

                                                ], ), ),
                                    per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per(
                                        node = [

                                            ], ), ),
                                wall_clock = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock(),
                                jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs(),
                                accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing(), ),
                            factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            min = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min(
                                priority_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold(
                                    set = True,
                                    infinite = True,
                                    number = 56, ), ), ),
                        name = '',
                        preempt = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt(
                            list = [
                                ''
                                ],
                            mode = [
                                'DISABLED'
                                ],
                            exempt_time = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_priority.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        usage_factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_factor(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        usage_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_threshold(
                            set = True,
                            infinite = True,
                            number = 1.337, ), )
                    ],
        )
        """

    def testV0041OpenapiSlurmdbdQosResp(self):
        """Test V0041OpenapiSlurmdbdQosResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
