# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_rollup_stats_monthly import V0042RollupStatsMonthly


class TestV0042RollupStatsMonthly(unittest.TestCase):
    """V0042RollupStatsMonthly unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042RollupStatsMonthly:
        """Test V0042RollupStatsMonthly
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042RollupStatsMonthly`
        """
        model = V0042RollupStatsMonthly()
        if include_optional:
            return V0042RollupStatsMonthly(
                count = 56,
                last_run = 56,
                duration = slurmrestpy.models.v0_0_42_rollup_stats_monthly_duration.v0_0_42_rollup_stats_monthly_duration(
                    last = 56,
                    max = 56,
                    time = 56, )
            )
        else:
            return V0042RollupStatsMonthly(
        )
        """

    def testV0042RollupStatsMonthly(self):
        """Test V0042RollupStatsMonthly"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
