# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_assoc_max_per import V0042AssocMaxPer


class TestV0042AssocMaxPer(unittest.TestCase):
    """V0042AssocMaxPer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042AssocMaxPer:
        """Test V0042AssocMaxPer
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042AssocMaxPer`
        """
        model = V0042AssocMaxPer()
        if include_optional:
            return V0042AssocMaxPer(
                account = slurmrestpy.models.v0_0_42_assoc_max_per_account.v0_0_42_assoc_max_per_account(
                    wall_clock = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ), )
            )
        else:
            return V0042AssocMaxPer(
        )
        """

    def testV0042AssocMaxPer(self):
        """Test V0042AssocMaxPer"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
