# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode,
)


class TestV0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode(unittest.TestCase):
    """V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode:
        """Test V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode`
        """
        model = V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode()
        if include_optional:
            return V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode(
                status = [
                    'INVALID'
                    ],
                return_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code(
                    set = True,
                    infinite = True,
                    number = 56, ),
                signal = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal(
                    id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    name = '', )
            )
        else:
            return V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode(
        )
        """

    def testV0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode(self):
        """Test V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
